# Generated by Django 4.2.3 on 2023-07-17 11:41

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ('plannings', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='event',
            name='date',
            field=models.DateField(verbose_name='Date'),
        ),
        migrations.AlterField(
            model_name='event',
            name='title',
            field=models.CharField(max_length=100, verbose_name='Title'),
        ),
    ]
